@@ -1,15 +1,19 @@
 #!/usr/bin/env python
 
-import unittest
+import copy
 import difflib
+import lxml
+import re
+import six
+import tempfile
+import unittest
 import xml2rfc
 import xml2rfc.utils
-import lxml
-import tempfile
-import re
+
+from xml2rfc.walkpdf import xmldoc
 
 try:
-    import debug
+    from xml2rfc import debug
     assert debug
 except ImportError:
     pass
@@ -21,7 +25,7 @@ def arrstrip(arr):
     return arr
 
 
-def diff_test(case, valid, test, failpath):
+def diff_test(case, valid, test, failpath, format):
     """ Compare two strings.  If not equal, fail with a useful diff and save
         second string to a file.
     """
@@ -29,7 +33,7 @@ def diff_test(case, valid, test, failpath):
     test  = str(test)
     valid = str(valid)
     # replace the current version with someting static, if present
-    test  =  test.replace(xml2rfc.__version__, 'N.N.N')
+    test  =  str(test.replace(xml2rfc.__version__, 'N.N.N'))
     validarr = [line.rstrip() for line in valid.splitlines()]
     testarr = [line.rstrip() for line in test.splitlines()]
     if testarr != validarr:
@@ -37,13 +41,13 @@ def diff_test(case, valid, test, failpath):
         fh = open(failpath, 'w')
         fh.write(test)
         fh.close()
-        case.fail("Output doesn't match, file saved to %s.\nDIFF:\n%s" % (failpath, '\n'.join(diff)))
+        case.fail("Output doesn't match for %s, file saved to %s.\nDIFF:\n%s" % (format, failpath, '\n'.join(diff)))
 
 def strip_formatting_whitespace(text):
     """ We use non-breaking space, non-breaking hyphen
         internally for formattin purposes - they need to be cleaned out
     """
-    return text.replace(u'\u00A0', ' ').replace(u'\u2011', '-')
+    return text.replace(u'\u00A0', ' ').replace(u'\u2011', '-').replace(u'\uE060', '')
 
 class XmlRfcDummy():
     """ Dummy rfc used for test fixtures """
@@ -147,7 +151,7 @@ output_format = [
     {
         "ext": "html",
         "spacefix": lambda x: x,
-        "unicodefix": lambda x: x,
+        "unicodefix": xml2rfc.utils.safeReplaceUnicode,
         "slashfix": xml2rfc.utils.safeTagSlashedWords,
         "writer": xml2rfc.HtmlRfcWriter,
         "postrendering": html_post_rendering,
@@ -207,7 +211,7 @@ class WriterElementTest(unittest.TestCase):
             slashfix(element)
             testfunc(element)
             output = postrendering('\n'.join(arrstrip(postprocessing(writer.buf))))  # Don't care about initial blank
-            diff_test(self, valid, output, validpath.replace('valid', 'failed'))
+            diff_test(self, valid, output, validpath.replace('valid', 'failed'), format['ext'])
 
     def test_references(self):
         return self.function_test('references', 'write_reference_list')
@@ -285,20 +289,20 @@ class WriterRootTest(unittest.TestCase):
     def header_footer_test(self):
         output = '\n'.join(self.writer._make_footer_and_header(1))
         output = strip_formatting_whitespace(output)
-        diff_test(self, self.valid, output, self.failpath)
+        diff_test(self, self.valid, output, self.failpath, 'txt')
 
     def top_test(self):
         self.writer.write_top(self.writer._prepare_top_left(), 
                               self.writer._prepare_top_right())
         output = '\n'.join(self.writer.buf)  # Care about initial blank
         output = strip_formatting_whitespace(output)
-        diff_test(self, self.valid, output, self.failpath)
+        diff_test(self, self.valid, output, self.failpath, 'txt')
 
     def status_test(self):
         self.writer.write_status_section()
         output = '\n'.join(arrstrip(self.writer.buf))  # Don't care about initial blank
         output = strip_formatting_whitespace(output)
-        diff_test(self, self.valid, output, self.failpath)
+        diff_test(self, self.valid, output, self.failpath, 'txt')
 
 
 class WriterDraftTest(WriterRootTest):
@@ -448,5 +452,47 @@ class WriterRfcTest(WriterRootTest):
         self.set_valid('tests/valid/status_independent_exp.txt')
         return self.status_test()
 
+
+def pdfwriter(path):
+    """ Parse a minimal RFC tree and instantiate a writer """
+    parser = xml2rfc.XmlRfcParser(path, quiet=True)
+    xmlrfc = parser.parse()
+    writer = xml2rfc.writers.pdf.PdfWriter(xmlrfc, quiet=True, )
+    return writer
+
+elements_writer = pdfwriter('tests/input/elements.xml')
+try:
+    elements_pdfdoc = elements_writer.pdf() # has side effects on .root
+except Exception as e:
+    print(e)
+    raise
+elements_root   = elements_writer.root
+elements_pdfxml = xmldoc(None, bytes=elements_pdfdoc)
+
+class PdfWriterTests(unittest.TestCase):
+
+    def setUp(self):
+        xml2rfc.log.quiet = True
+        self.pdfxml = copy.deepcopy(elements_pdfxml)
+        self.root = copy.deepcopy(elements_root)
+
+
+    def test_text_content(self):
+        def norm(t):
+            return re.sub(r'\s+', ' ', t).strip()
+        #
+        text = norm('\n'.join( p.text for p in self.pdfxml.xpath('.//Page/text') ))
+        for e in self.root.xpath('./middle//*'):
+            if e.text and e.text.strip() and e.tag not in xml2rfc.util.unicode.unicode_content_tags:
+                t =  norm(e.text.split(None, 1)[0])
+                self.assertIn(t, text)
+
+    def test_included_fonts(self):
+        if xml2rfc.HAVE_WEASYPRINT and xml2rfc.HAVE_PYCAIRO and xml2rfc.HAVE_CAIRO and xml2rfc.HAVE_PANGO:
+            font_families = set([ f.text for f in self.pdfxml.xpath('.//FontFamily') ])
+            for script in self.root.get('scripts').split(','):
+                family = xml2rfc.util.fonts.get_noto_serif_family_for_script(script)
+                self.assertIn(family, font_families, 'Missing font match for %s' % script)
+
 if __name__ == '__main__':
     unittest.main()
