@@ -2,10 +2,11 @@
 # Copyright The IETF Trust 2011, All Rights Reserved
 # --------------------------------------------------
 
-import sys
 import lxml.etree
 import xml2rfc
 import datetime
+from io import open
+from xml2rfc.writers.base import default_options
 
 class ExpandedXmlWriter:
     """ Writes a duplicate XML file but with all references expanded """
@@ -13,10 +14,11 @@ class ExpandedXmlWriter:
     # Note -- we don't need to subclass BaseRfcWriter because the behavior
     # is so different and so trivial
 
-    def __init__(self, xmlrfc, quiet=False, verbose=False, date=datetime.date.today()):
+    def __init__(self, xmlrfc, quiet=None, options=default_options, date=datetime.date.today()):
+        if not quiet is None:
+            options.quiet = quiet
         self.root = xmlrfc.getroot()
-        self.quiet = quiet
-        self.verbose = verbose
+        self.options = options
 
     def post_process_lines(self, lines):
         output = [ line.replace(u'\u00A0', ' ') for line in lines ]
@@ -26,17 +28,13 @@ class ExpandedXmlWriter:
         """ Public method to write the XML document to a file """
 
         # Use lxml's built-in serialization
-        file = open(filename, 'w')
+        file = open(filename, 'w', encoding='ascii')
         text = lxml.etree.tostring(self.root.getroottree(), 
                                        xml_declaration=True, 
                                        encoding='ascii',
                                        doctype='<!DOCTYPE rfc SYSTEM "rfc2629.dtd">',
                                        pretty_print=True)
+        file.write(text.decode('ascii'))
 
-        if sys.version > '3':
-            file.write(text.decode())
-        else:
-            file.write(text)
-
-        if not self.quiet:
-            xml2rfc.log.write('Created file', filename)
+        if not self.options.quiet:
+            xml2rfc.log.write(' Created file', filename)
