@@ -4,6 +4,8 @@
 
 # Python libs
 import datetime
+import calendar
+import six
 
 try:
     import debug
@@ -82,7 +84,7 @@ class PaginatedTextRfcWriter(RawTextRfcWriter):
             # Extend the number of lines if greater
             if need > needLines:
                 needLines = need
-        self.break_hints[where] = (int(needLines), type)
+        self.break_hints[where] = (needLines, type)
             
 
     def write_with_break_hint(self, writer, type, *args, **kwargs):
@@ -99,8 +101,14 @@ class PaginatedTextRfcWriter(RawTextRfcWriter):
 
     def needLines(self, count):
         """Deal with the PI directive needLines"""
+        if isinstance(count, six.string_types):
+            if count.isdigit():
+                count = int(count)
+            else:
+                xml2rfc.log.warn('Expected a numeric value for needLines, but got "%s".  Using 3.' % count)
+                count = 3
         try:
-            if int(count) < 0:
+            if count < 0:
                 self._set_break_hint(1, 'break', len(self.buf))
             else:
                 self._set_break_hint(count, 'raw', len(self.buf))
@@ -192,10 +200,12 @@ class PaginatedTextRfcWriter(RawTextRfcWriter):
         date = self.r.find('front/date')
         if date is not None:
             month = date.attrib.get('month', '')
+            if month.isdigit():
+                month = calendar.month_name[int(month)]
             year = date.attrib.get('year', '')
             self.right_header = month + ' ' + year
         authors = self.r.findall('front/author')
-        surnames = [ a.attrib.get('surname') for a in authors if a.attrib.get('surname', None) ]
+        surnames = list(filter(None, [ a.get('asciiSurname', a.get('surname')) for a in authors ]))
         if len(surnames) == 1:
             self.left_footer = surnames[0]
         elif len(surnames) == 2:
